Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(326)

Unified Diff: content/browser/browsing_data/clear_site_data_throttle.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/browsing_data/clear_site_data_throttle.cc
diff --git a/content/browser/browsing_data/clear_site_data_throttle.cc b/content/browser/browsing_data/clear_site_data_throttle.cc
index 4666c04cf47aec4d400d04b33fcbb21ca11bafa5..50819490b9a4216c5a55c0187a49d1aadb6f2a0c 100644
--- a/content/browser/browsing_data/clear_site_data_throttle.cc
+++ b/content/browser/browsing_data/clear_site_data_throttle.cc
@@ -346,7 +346,7 @@ bool ClearSiteDataThrottle::HandleHeader() {
return false;
}
// Only accept the header on secure non-unique origins.
if (!IsOriginSecure(GetCurrentURL())) {
delegate_->AddMessage(GetCurrentURL(),
"Not supported for insecure origins.",
@@ -355,8 +355,8 @@ bool ClearSiteDataThrottle::HandleHeader() {
}
url::Origin origin(GetCurrentURL());
- if (origin.unique()) {
- delegate_->AddMessage(GetCurrentURL(), "Not supported for unique origins.",
+ if (origin.opaque()) {
+ delegate_->AddMessage(GetCurrentURL(), "Not supported for opaque origins.",
CONSOLE_MESSAGE_LEVEL_ERROR);
return false;
}
@@ -346,7 +346,7 @@ bool ClearSiteDataThrottle::HandleHeader() {
return false;
}
- // Only accept the header on secure non-unique origins.
+ // Only accept the header on secure non-opaque origins.
if (!IsOriginSecure(GetCurrentURL())) {
delegate_->AddMessage(GetCurrentURL(),

Powered by Google App Engine
This is Rietveld 408576698